@@ -1,5 +1,6 @@
 import json
 from ..response.command_result import CommandSingleResult, MSGStatusCodes
+from inspect import currentframe, getframeinfo
 
 
 class ExceptionError(Exception):
@@ -13,6 +14,11 @@ class ExceptionError(Exception):
         self.message = message
         self.ProtoError = True
 
+        # involve stack tracking
+        previous_frame = currentframe().f_back
+        (filename, line_number, function_name, lines, index) = getframeinfo(previous_frame)
+        self.payload = f'{self.payload} \n {filename} - {line_number}'
+
     def __str__(self):
         return '\n'.join([self.message, self.payload or ''])
 
